Usage
=====

``Ycleptic`` primarily exposes the :class:`Yclept` class to inherit in your own applications.  It also has a command-line interface with two subcommands: ``yclept config-help`` and ``yclept make-doc``.  The former provides interactive help for the configuration file, and the latter generates documentation from the base configuration file.

.. toctree:: 
   :maxdepth: 1

   usage/class
   usage/the_base_config
   usage/the_user_config
   usage/interactive_help
   usage/resource_file
   usage/yclept_config-help
   usage/yclept_makedoc